'''Support basic VO conesearch capabilities.

The basic idea is to isolate the user from the details of which URLs should be
used for any particular catalog. Indeed, the general approach is to support 
a variety of servers and try each in order until one is found that is responsive. 
For this reason, only the basic conesearch parameter are supported for the generic 
catalog name. The details of which servers to try is held in a local configuration
file. This file is updated periodically from an STScI server (or mirror) to keep
it current.
'''

import webquery
import vosconfig
import tempfile
import table

def conesearch(catalog=None,ra=None,dec=None,sr=None):
    '''Do a conesearch on the selected catalog.
    
    By default, it returns a record array.
    This intial version writes a temporary file. When completed it deletes the file.
    For reliabilty, a small query is tried to see if the server is responsive.
    '''
    # Try different servers until successful
    # This is currently pointless until a version of webquery is made that 
    # can timeout !!!!
    coneconfig = vosconfig.get_vo_service_config()['CONESEARCH']
    try:
        catconfig = coneconfig[catalog]
    except KeyError:
        print "Specified catalog not supported"
        print "Use listcatalogs() to see list of supported catalogs."
        raise KeyError
    urllist = catconfig['urllist']
    # This currently will hang on the first server if it isn't alive
    # Needs a timeout version of webquery to correct.
    for url in urllist:   
        # Create temporary file
        fo = tempfile.TemporaryFile(suffix='.xml',mode='w+b')
        try:
            info = webquery.webget(url,fo,ra=ra,dec=dec,sr=sr)
        except IOError:
            print "warning, failed to connect to: ", url
            continue
        fo.seek(0)
        tab = table.parse_single_table(fo)
        if has_errors(tab):
            print "Query resulted in errors"
            raise RuntimeError
        else:
            return tab.array

def has_errors(tab):
    '''Determine if conesearch query resulted in a VOTable reporting errors
    
    Returns True if errors were found. Not yet implemented'''
    return False        